@@ -8,11 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_kms._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-neptune", "1.91.0", __name__[0:-6], "aws-neptune@1.91.0.jsii.tgz"
+    "@aws-cdk/aws-neptune", "1.93.0", __name__[0:-6], "aws-neptune@1.93.0.jsii.tgz"
 )
 
 __all__ = [
